@@ -14,8 +14,8 @@ async fn run(
     tm.move_to(8, 8);
     tm.set_fgcolor(textmode::color::GREEN);
     tm.write_str("bar");
-    tm.move_to(11, 11);
-    tm.set_fgcolor(vt100::Color::Default);
+    tm.move_relative(3, 0);
+    tm.set_fgcolor(textmode::Color::Default);
     tm.write_str("baz");
     input.read_key().await?;
     tm.refresh().await?;
@@ -47,8 +47,8 @@ fn main() {
     tm.move_to(8, 8);
     tm.set_fgcolor(textmode::color::GREEN);
     tm.write_str("bar");
-    tm.move_to(11, 11);
-    tm.set_fgcolor(vt100::Color::Default);
+    tm.move_relative(3, 0);
+    tm.set_fgcolor(textmode::Color::Default);
     tm.write_str("baz");
     input.read_key().unwrap();
     tm.refresh().unwrap();
